=======
Catalog
=======
.. currentmodule:: polars


Unity Catalog
~~~~~~~~~~~~~

Interface with Unity catalogs.

.. autosummary::
   :toctree: api/

   Catalog
   Catalog.list_catalogs
   Catalog.list_schemas
   Catalog.list_tables
   Catalog.get_table_info
   Catalog.scan_table
